
/*
 * This method demonstates the use of abstact classes. The class can have
 * its own member data like firstName and lastName. These are common to all
 * employees. The code to convert the name to a string can be used by all 
 * classes which extend Employee. However, the method that computes the
 * earnings must be written for each subclass because we need more
 * specific information about the employee to do this computation.
 */
public abstract class Employee {

	   private String firstName;
	   private String lastName;

	   // Constructor
	   public Employee( String first, String last )
	   {
	      firstName = first;
	      lastName = last;
	   }
	   
	   // Return the first name
	   public String getFirstName() { return firstName; }

	   // Return the last name
	   public String getLastName() { return lastName; }

	   public String toString()
	      { return firstName + ' ' + lastName; }

	   // Abstract method that must be implemented for each 
	   // derived class of Employee from which objects 
	   // are instantiated.
	   public abstract double earnings(); 
}
